@@ -20,11 +20,12 @@
 */
 
 #include "chmodjob.h"
+#include "../pathhelpers_p.h"
 
 #include <KLocalizedString>
 #include <KUser>
-#include <QtCore/QFile>
-#include <QtCore/QLinkedList>
+#include <QFile>
+#include <QLinkedList>
 #include <QDebug>
 
 
@@ -87,6 +88,10 @@ public:
         if (!(flags & HideProgressInfo)) {
             KIO::getJobTracker()->registerJob(job);
         }
+        if (!(flags & NoPrivilegeExecution)) {
+            job->d_func()->m_privilegeExecutionEnabled = true;
+            job->d_func()->m_operationType = ChangeAttr;
+        }
         return job;
     }
 };
@@ -129,8 +134,7 @@ void ChmodJobPrivate::_k_processList()
             if (item.isDir() && m_recursive) {
                 //qDebug() << "ChmodJob::processList dir -> listing";
                 KIO::ListJob *listJob = KIO::listRecursive(item.url(), KIO::HideProgressInfo);
-                q->connect(listJob, SIGNAL(entries(KIO::Job *,
-                                                   const KIO::UDSEntryList &)),
+                q->connect(listJob, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
                            SLOT(_k_slotEntries(KIO::Job*,KIO::UDSEntryList)));
                 q->addSubjob(listJob);
                 return; // we'll come back later, when this one's finished
@@ -158,7 +162,7 @@ void ChmodJobPrivate::_k_slotEntries(KIO::Job *, const KIO::UDSEntryList &list)
 
             ChmodInfo info;
             info.url = m_lstItems.first().url(); // base directory
-            info.url.setPath(info.url.path() + '/' + relativePath);
+            info.url.setPath(concatPaths(info.url.path(), relativePath));
             int mask = m_mask;
             // Emulate -X: only give +x to files that had a +x bit already
             // So the check is the opposite : if the file had no x bit, don't touch x bits
@@ -211,6 +215,7 @@ void ChmodJobPrivate::_k_chmodNextFile()
                     case Result_AutoSkip:
                         m_bAutoSkipFiles = true;
                     // fall through
+                        Q_FALLTHROUGH();
                     case Result_Skip:
                         QMetaObject::invokeMethod(q, "_k_chmodNextFile", Qt::QueuedConnection);
                         return;
@@ -231,6 +236,7 @@ void ChmodJobPrivate::_k_chmodNextFile()
         /*qDebug() << "chmod'ing" << info.url
                       << "to" << QString::number(info.permissions,8);*/
         KIO::SimpleJob *job = KIO::chmod(info.url, info.permissions);
+        job->setParentJob(q);
         // copy the metadata for acl and default acl
         const QString aclString = q->queryMetaData(QStringLiteral("ACL_STRING"));
         const QString defaultAclString = q->queryMetaData(QStringLiteral("DEFAULT_ACL_STRING"));
