@@ -35,22 +35,22 @@
 #include <sys/utsname.h>
 #endif
 
-#include <QtCore/QCoreApplication>
+#include <QCoreApplication>
 #include <QUrl>
-#include <QtNetwork/QSslSocket>
-#include <QtNetwork/QHostAddress>
-#include <QtNetwork/QHostInfo>
+#include <QSslSocket>
+#include <QHostAddress>
+#include <QHostInfo>
 #include <QDBusConnection>
 #include <QDBusReply>
 #include <QDBusInterface>
-#include <QtCore/QCache>
+#include <QCache>
 #include <QLocale>
 #include <qstandardpaths.h>
 #include <qmimedatabase.h>
 
 #if !defined(QT_NO_NETWORKPROXY) && (defined (Q_OS_WIN32) || defined(Q_OS_MAC))
-#include <QtNetwork/QNetworkProxyFactory>
-#include <QtNetwork/QNetworkProxyQuery>
+#include <QNetworkProxyFactory>
+#include <QNetworkProxyQuery>
 #endif
 
 #include <kio_version.h>
@@ -204,22 +204,21 @@ bool KProtocolManagerPrivate::shouldIgnoreProxyFor(const QUrl &url)
         QByteArray host = qhost.toLatin1();
         const QString qno_proxy = noProxyFor.trimmed().toLower();
         const QByteArray no_proxy = qno_proxy.toLatin1();
-        isMatch = revmatch(host, no_proxy);
+        isMatch = revmatch(host.constData(), no_proxy.constData());
 
         // If no match is found and the request url has a port
         // number, try the combination of "host:port". This allows
         // users to enter host:port in the No-proxy-For list.
         if (!isMatch && url.port() > 0) {
-            qhost += QL1C(':');
-            qhost += QString::number(url.port());
+            qhost += QL1C(':') + QString::number(url.port());
             host = qhost.toLatin1();
-            isMatch = revmatch(host, no_proxy);
+            isMatch = revmatch(host.constData(), no_proxy.constData());
         }
 
         // If the hostname does not contain a dot, check if
         // <local> is part of noProxy.
-        if (!isMatch && !host.isEmpty() && (strchr(host, '.') == nullptr)) {
-            isMatch = revmatch("<local>", no_proxy);
+        if (!isMatch && !host.isEmpty() && (strchr(host.constData(), '.') == nullptr)) {
+            isMatch = revmatch("<local>", no_proxy.constData());
         }
     }
 
@@ -311,7 +310,7 @@ QString KProtocolManagerPrivate::readNoProxyFor()
 {
     QString noProxy = config()->group("Proxy Settings").readEntry("NoProxyFor");
     if (proxyType() == KProtocolManager::EnvVarProxy) {
-        noProxy = QString::fromLocal8Bit(qgetenv(noProxy.toLocal8Bit()));
+        noProxy = QString::fromLocal8Bit(qgetenv(noProxy.toLocal8Bit().constData()));
     }
     return noProxy;
 }
@@ -424,7 +423,7 @@ QString KProtocolManager::cacheDir()
 {
     PRIVATE_DATA;
     QMutexLocker lock(&d->mutex);
-    return http_config().readPathEntry("CacheDir", QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + "/kio_http");
+    return http_config().readPathEntry("CacheDir", QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + QLatin1String("/kio_http"));
 }
 
 int KProtocolManager::maxCacheAge()
@@ -476,10 +475,10 @@ QString KProtocolManagerPrivate::proxyFor(const QString &protocol)
 
     if (index > -1)  {
         bool ok = false;
-        const QString portStr(proxyStr.right(proxyStr.length() - index - 1));
+        const QStringRef portStr(proxyStr.rightRef(proxyStr.length() - index - 1));
         portStr.toInt(&ok);
         if (ok) {
-            proxyStr = proxyStr.left(index) + QL1C(':') + portStr;
+            proxyStr = proxyStr.leftRef(index) + QL1C(':') + portStr;
         } else {
             proxyStr.clear();
         }
@@ -506,6 +505,7 @@ QStringList KProtocolManagerPrivate::getSystemProxyFor(const QUrl &url)
 #if !defined(QT_NO_NETWORKPROXY) && (defined(Q_OS_WIN32) || defined(Q_OS_MAC))
     QNetworkProxyQuery query(url);
     const QList<QNetworkProxy> proxyList = QNetworkProxyFactory::systemProxyForQuery(query);
+    proxies.reserve(proxyList.size());
     Q_FOREACH (const QNetworkProxy &proxy, proxyList) {
         QUrl url;
         const QNetworkProxy::ProxyType type = proxy.type();
@@ -532,7 +532,7 @@ QStringList KProtocolManagerPrivate::getSystemProxyFor(const QUrl &url)
     QString proxyVar(proxyFor(url.scheme()));
     // Check for SOCKS proxy, if not proxy is found for given url.
     if (!proxyVar.isEmpty()) {
-        const QString proxy(QString::fromLocal8Bit(qgetenv(proxyVar.toLocal8Bit())).trimmed());
+        const QString proxy(QString::fromLocal8Bit(qgetenv(proxyVar.toLocal8Bit().constData())).trimmed());
         if (!proxy.isEmpty()) {
             proxies << proxy;
         }
@@ -540,10 +540,11 @@ QStringList KProtocolManagerPrivate::getSystemProxyFor(const QUrl &url)
     // Add the socks proxy as an alternate proxy if it exists,
     proxyVar = proxyFor(QStringLiteral("socks"));
     if (!proxyVar.isEmpty()) {
-        QString proxy = QString::fromLocal8Bit(qgetenv(proxyVar.toLocal8Bit())).trimmed();
+        QString proxy = QString::fromLocal8Bit(qgetenv(proxyVar.toLocal8Bit().constData())).trimmed();
         // Make sure the scheme of SOCKS proxy is always set to "socks://".
         const int index = proxy.indexOf(QL1S("://"));
-        proxy = QL1S("socks://") + (index == -1 ? proxy : proxy.mid(index + 3));
+        const int offset = (index == -1) ? 0 : (index + 3);
+        proxy = QL1S("socks://") + proxy.midRef(offset);
         if (!proxy.isEmpty()) {
             proxies << proxy;
         }
@@ -588,7 +589,8 @@ QStringList KProtocolManager::proxiesForUrl(const QUrl &url)
             if (!proxy.isEmpty()) {
                 // Make sure the scheme of SOCKS proxy is always set to "socks://".
                 const int index = proxy.indexOf(QL1S("://"));
-                proxy = QStringLiteral("socks://") + (index == -1 ? proxy : proxy.mid(index + 3));
+                const int offset = (index == -1) ? 0 : (index + 3);
+                proxy = QL1S("socks://") + proxy.midRef(offset);
                 proxyList << proxy;
             }
         }
@@ -812,41 +814,38 @@ QString KProtocolManager::defaultUserAgent(const QString &_modifiers)
         supp += platform();
 
         if (sysInfoFound) {
-            if (modifiers.contains('o')) {
-                supp += QL1S("; ");
-                supp += systemName;
-                if (modifiers.contains('v')) {
-                    supp += QL1C(' ');
-                    supp += systemVersion;
+            if (modifiers.contains(QL1C('o'))) {
+                supp += QL1S("; ") + systemName;
+                if (modifiers.contains(QL1C('v'))) {
+                    supp += QL1C(' ') + systemVersion;
                 }
 
-                if (modifiers.contains('m')) {
-                    supp += QL1C(' ');
-                    supp += machine;
+                if (modifiers.contains(QL1C('m'))) {
+                    supp += QL1C(' ') + machine;
                 }
             }
 
-            if (modifiers.contains('l')) {
-                supp += QL1S("; ");
-                supp += QLocale::languageToString(QLocale().language());
+            if (modifiers.contains(QL1C('l'))) {
+                supp += QL1S("; ") + QLocale::languageToString(QLocale().language());
             }
         }
 
         // Full format: Mozilla/5.0 (Linux
-        d->useragent = QStringLiteral("Mozilla/5.0 (");
-        d->useragent += supp;
-        d->useragent += QStringLiteral(") KHTML/");
-        d->useragent += QString::number(KIO_VERSION_MAJOR);
-        d->useragent += QL1C('.');
-        d->useragent += QString::number(KIO_VERSION_MINOR);
-        d->useragent += QL1C('.');
-        d->useragent += QString::number(KIO_VERSION_PATCH);
-        d->useragent += QStringLiteral(" (like Gecko) Konqueror/");
-        d->useragent += QString::number(KIO_VERSION_MAJOR);
-        d->useragent += QStringLiteral(" KIO/");
-        d->useragent += QString::number(KIO_VERSION_MAJOR);
-        d->useragent += QL1C('.');
-        d->useragent += QString::number(KIO_VERSION_MINOR);
+        d->useragent =
+            QL1S("Mozilla/5.0 (") +
+            supp +
+            QL1S(") KHTML/") +
+            QString::number(KIO_VERSION_MAJOR) +
+            QL1C('.') +
+            QString::number(KIO_VERSION_MINOR) +
+            QL1C('.') +
+            QString::number(KIO_VERSION_PATCH) +
+            QL1S(" (like Gecko) Konqueror/") +
+            QString::number(KIO_VERSION_MAJOR) +
+            QL1S(" KIO/") +
+            QString::number(KIO_VERSION_MAJOR) +
+            QL1C('.') +
+            QString::number(KIO_VERSION_MINOR);
     } else {
         QString appName = QCoreApplication::applicationName();
         if (appName.isEmpty() || appName.startsWith(QLatin1String("kcmshell"), Qt::CaseInsensitive)) {
@@ -855,15 +854,15 @@ QString KProtocolManager::defaultUserAgent(const QString &_modifiers)
 
         QString appVersion = QCoreApplication::applicationVersion();
         if (appVersion.isEmpty()) {
-            appVersion += QString::number(KIO_VERSION_MAJOR);
-            appVersion += QL1C('.');
-            appVersion += QString::number(KIO_VERSION_MINOR);
-            appVersion += QL1C('.');
-            appVersion += QString::number(KIO_VERSION_PATCH);
+            appVersion +=
+                QString::number(KIO_VERSION_MAJOR) +
+                QL1C('.') +
+                QString::number(KIO_VERSION_MINOR) +
+                QL1C('.') +
+                QString::number(KIO_VERSION_PATCH);
         }
 
-        appName += QL1C('/');
-        appName += appVersion;
+        appName += QL1C('/') + appVersion;
 
         agentStr.replace(QL1S("%appversion%"), appName, Qt::CaseInsensitive);
 
@@ -878,18 +877,18 @@ QString KProtocolManager::defaultUserAgent(const QString &_modifiers)
             agentStr.replace(QL1S("%platform%"), platform(), Qt::CaseInsensitive);
 
             // Operating system (e.g. Linux)
-            if (modifiers.contains('o')) {
+            if (modifiers.contains(QL1C('o'))) {
                 agentStr.replace(QL1S("%osname%"), systemName, Qt::CaseInsensitive);
 
                 // OS version (e.g. 2.6.36)
-                if (modifiers.contains('v')) {
+                if (modifiers.contains(QL1C('v'))) {
                     agentStr.replace(QL1S("%osversion%"), systemVersion, Qt::CaseInsensitive);
                 } else {
                     agentStr.remove(QStringLiteral("%osversion%"), Qt::CaseInsensitive);
                 }
 
                 // Machine type (i686, x86-64, etc.)
-                if (modifiers.contains('m')) {
+                if (modifiers.contains(QL1C('m'))) {
                     agentStr.replace(QL1S("%systype%"), machine, Qt::CaseInsensitive);
                 } else {
                     agentStr.remove(QStringLiteral("%systype%"), Qt::CaseInsensitive);
@@ -901,7 +900,7 @@ QString KProtocolManager::defaultUserAgent(const QString &_modifiers)
             }
 
             // Language (e.g. en_US)
-            if (modifiers.contains('l')) {
+            if (modifiers.contains(QL1C('l'))) {
                 agentStr.replace(QL1S("%language%"), QLocale::languageToString(QLocale().language()), Qt::CaseInsensitive);
             } else {
                 agentStr.remove(QStringLiteral("%language%"), Qt::CaseInsensitive);
@@ -933,26 +932,22 @@ QString KProtocolManager::userAgentForApplication(const QString &appName, const
     QString systemName, systemVersion, machine, info;
 
     if (getSystemNameVersionAndMachine(systemName, systemVersion, machine)) {
-        info +=  systemName;
-        info += QL1C('/');
-        info += systemVersion;
-        info += QStringLiteral("; ");
+        info += systemName + QL1C('/') + systemVersion + QL1S("; ");
     }
 
-    info += QStringLiteral("KDE/");
-    info += QString::number(KIO_VERSION_MAJOR);
-    info += QL1C('.');
-    info += QString::number(KIO_VERSION_MINOR);
-    info += QL1C('.');
-    info += QString::number(KIO_VERSION_PATCH);
+    info +=
+        QL1S("KDE/") +
+        QString::number(KIO_VERSION_MAJOR) +
+        QL1C('.') +
+        QString::number(KIO_VERSION_MINOR) +
+        QL1C('.') +
+        QString::number(KIO_VERSION_PATCH);
 
     if (!machine.isEmpty()) {
-        info += QStringLiteral("; ");
-        info += machine;
+        info += QL1S("; ") + machine;
     }
 
-    info += QStringLiteral("; ");
-    info += extraInfo.join(QStringLiteral("; "));
+    info += QL1S("; ") + extraInfo.join(QStringLiteral("; "));
 
     return (appName + QL1C('/') + appVersion + QStringLiteral(" (") + info + QL1C(')'));
 }
@@ -983,9 +978,9 @@ bool KProtocolManager::getSystemNameVersionAndMachine(
     if (0 != uname(&unameBuf)) {
         return false;
     }
-    systemName = unameBuf.sysname;
-    systemVersion = unameBuf.release;
-    machine = unameBuf.machine;
+    systemName = QString::fromUtf8(unameBuf.sysname);
+    systemVersion = QString::fromUtf8(unameBuf.release);
+    machine = QString::fromUtf8(unameBuf.machine);
 #endif
     return true;
 }
@@ -1035,11 +1030,10 @@ QString KProtocolManager::acceptLanguagesHeader()
     Q_FOREACH (const QString &lang, languageListFinal) {
         header += lang;
         if (prio < 10) {
-            header += QL1S(";q=0.");
-            header += QString::number(prio);
+            header += QL1S(";q=0.") + QString::number(prio);
         }
         // do not add cosmetic whitespace in here : it is less compatible (#220677)
-        header += QL1S(",");
+        header += QL1C(',');
         if (prio > 1) {
             --prio;
         }
@@ -1049,8 +1043,8 @@ QString KProtocolManager::acceptLanguagesHeader()
     // Some of the languages may have country specifier delimited by
     // underscore, or modifier delimited by at-sign.
     // The header should use dashes instead.
-    header.replace('_', '-');
-    header.replace('@', '-');
+    header.replace(QL1C('_'), QL1C('-'));
+    header.replace(QL1C('@'), QL1C('-'));
 
     return header;
 }
@@ -1104,6 +1098,9 @@ QString KProtocolManager::proxyConfigScript()
 
 static KProtocolInfoPrivate *findProtocol(const QUrl &url)
 {
+    if (!url.isValid()) {
+        return nullptr;
+    }
     QString protocol = url.scheme();
     if (!KProtocolInfo::proxiedBy(protocol).isEmpty()) {
         QString dummy;
