@@ -21,10 +21,10 @@
 #ifndef UDSENTRY_H
 #define UDSENTRY_H
 
-#include <QtCore/QString>
-#include <QtCore/QList>
-#include <QtCore/QSharedData>
-#include <QtCore/QMetaType>
+#include <QString>
+#include <QList>
+#include <QSharedData>
+#include <QMetaType>
 #include <QtGlobal>
 #include <qplatformdefs.h>
 
@@ -35,7 +35,14 @@ namespace KIO
 class UDSEntry;
 }
 
-void debugUDSEntry(QDebug stream, const KIO::UDSEntry &entry);
+KIOCORE_EXPORT QDataStream &operator<< (QDataStream &s, const KIO::UDSEntry &a);
+KIOCORE_EXPORT QDataStream &operator>> (QDataStream &s, KIO::UDSEntry &a);
+
+/**
+ * Support for qDebug() << aUDSEntry
+ * \since 5.22
+ */
+KIOCORE_EXPORT QDebug operator<<(QDebug stream, const KIO::UDSEntry &entry);
 
 namespace KIO
 {
@@ -136,15 +143,33 @@ public:
      * insert field with string value
      * @param field numeric field id
      * @param value to set
+     * @deprecated since 5.48 in favor of fastInsert or replace
      */
-    void insert(uint field, const QString &value);
+    KIOCORE_DEPRECATED void insert(uint field, const QString &value);
 
     /**
      * insert field with numeric value
      * @param field numeric field id
      * @param l value to set
+     * @deprecated since 5.48 in favor of fastInsert or replace
      */
-    void insert(uint field, long long l);
+    KIOCORE_DEPRECATED void insert(uint field, long long l);
+
+    /**
+     * insert field with string value, it will assert if the field is already inserted. In that case, use replace() instead.
+     * @param field numeric field id
+     * @param value to set
+     * @since 5.48
+     */
+    void fastInsert(uint field, const QString &value);
+
+    /**
+     * insert field with numeric value, it will assert if the field is already inserted. In that case, use replace() instead.
+     * @param field numeric field id
+     * @param l value to set
+     * @since 5.48
+     */
+    void fastInsert(uint field, long long l);
 
     /**
      * count fields
@@ -308,9 +333,26 @@ public:
     };
 
 private:
-    friend class UDSEntryPrivate;
-    friend void ::debugUDSEntry(QDebug stream, const KIO::UDSEntry &entry);
     QSharedDataPointer<UDSEntryPrivate> d;
+    friend KIOCORE_EXPORT QDataStream& ::operator<< (QDataStream &s, const KIO::UDSEntry &a);
+    friend KIOCORE_EXPORT QDataStream& ::operator>> (QDataStream &s, KIO::UDSEntry &a);
+    friend KIOCORE_EXPORT QDebug (::operator<<) (QDebug stream, const KIO::UDSEntry &entry);
+public:
+    /**
+     * Replace or insert field with string value
+     * @param field numeric field id
+     * @param value to set
+     * @since 5.47
+     */
+    void replace(uint field, const QString &value);
+
+    /**
+     * Replace or insert field with numeric value
+     * @param field numeric field id
+     * @param l value to set
+     * @since 5.47
+     */
+    void replace(uint field, long long l);
 };
 
 }
@@ -339,15 +381,6 @@ namespace KIO
 typedef QList<UDSEntry> UDSEntryList;
 } // end namespace
 
-KIOCORE_EXPORT QDataStream &operator<< (QDataStream &s, const KIO::UDSEntry &a);
-KIOCORE_EXPORT QDataStream &operator>> (QDataStream &s, KIO::UDSEntry &a);
-
-/**
- * Support for qDebug() << aUDSEntry
- * \since 5.22
- */
-KIOCORE_EXPORT QDebug operator<<(QDebug stream, const KIO::UDSEntry &entry);
-
 Q_DECLARE_METATYPE(KIO::UDSEntry)
 
 #endif /*UDSENTRY_H*/
